# # apps/auth/views.py

# from sqlalchemy.orm import Session
# from apps.auth.models import User
# from config.database import get_db
# from utils.response import format_response
# import bcrypt

# async def socket_signup(sid, data):
#     db: Session = next(get_db())
#     try:
#         email = data.get('email')
#         username = data.get('username')
#         password = data.get('password')

#         if not email or not username or not password:
#             return format_response('error', 'Missing credentials')

#         user = db.query(User).filter(User.email == email).first()
#         if user:
#             return format_response('error', 'Email already exists')

#         # Hash the password and decode it to store as a string
#         hashed_password = bcrypt.hashpw(password.encode('utf-8'), bcrypt.gensalt()).decode('utf-8')
        
#         new_user = User(email=email, username=username, password=hashed_password)
#         db.add(new_user)
#         db.commit()

#         # Send a welcome email
#         from utils.email import send_welcome_email
#         await send_welcome_email(email, username)

#         return format_response('success', 'User registered successfully')
#     except Exception as e:
#         print(f"Error during socket signup: {e}")
#         db.rollback()  # Rollback in case of any error
#         return format_response('error', 'Signup failed')
#     finally:
#         db.close()

# async def socket_login(sid, data):
#     db: Session = next(get_db())
#     try:
#         email = data.get('email')
#         password = data.get('password')

#         user = db.query(User).filter(User.email == email).first()

#         if user and bcrypt.checkpw(password.encode('utf-8'), user.password.encode('utf-8')):
#             return format_response('success', f'Welcome {user.username}')
#         else:
#             return format_response('error', 'Invalid credentials')
#     except Exception as e:
#         print(f"Error during socket login: {e}")
#         db.rollback()  # Rollback in case of any error
#         return format_response('error', 'Login failed')
#     finally:
#         db.close()


# apps/auth/socket_views.py

from sqlalchemy.orm import Session
from apps.auth.models import User
from config.database import get_db
from utils.response import format_response
from apps.auth.serializers import serialize_user  # Importing the serializer
import bcrypt

async def socket_signup(sid, data):
    db: Session = next(get_db())
    try:
        email = data.get('email')
        username = data.get('username')
        password = data.get('password')

        if not email or not username or not password:
            return format_response('error', 'Missing credentials')

        user = db.query(User).filter(User.email == email).first()
        if user:
            return format_response('error', 'Email already exists')

        # Hash the password and decode it to store as a string
        hashed_password = bcrypt.hashpw(password.encode('utf-8'), bcrypt.gensalt()).decode('utf-8')
        
        new_user = User(email=email, username=username, password=hashed_password)
        db.add(new_user)
        db.commit()

        # Send a welcome email
        from utils.email import send_welcome_email
        await send_welcome_email(email, username)

        # Serialize the newly created user
        serialized_user = serialize_user(new_user)
        return format_response('success', 'User registered successfully', serialized_user)
    except Exception as e:
        print(f"Error during socket signup: {e}")
        db.rollback()  # Rollback in case of any error
        return format_response('error', 'Signup failed')
    finally:
        db.close()

async def socket_login(sid, data):
    db: Session = next(get_db())
    try:
        email = data.get('email')
        password = data.get('password')

        user = db.query(User).filter(User.email == email).first()

        if user and bcrypt.checkpw(password.encode('utf-8'), user.password.encode('utf-8')):
            serialized_user = serialize_user(user)  # Serialize user for response
            return format_response('success', f'Welcome {user.username}', serialized_user)
        else:
            return format_response('error', 'Invalid credentials')
    except Exception as e:
        print(f"Error during socket login: {e}")
        db.rollback()  # Rollback in case of any error
        return format_response('error', 'Login failed')
    finally:
        db.close()
